# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SageMaker'
prefix = 'sagemaker'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
CreateEndpoint = Action('CreateEndpoint')
CreateEndpointConfig = Action('CreateEndpointConfig')
CreateModel = Action('CreateModel')
CreateNotebookInstance = Action('CreateNotebookInstance')
CreatePresignedNotebookInstanceUrl = \
    Action('CreatePresignedNotebookInstanceUrl')
CreateTrainingJob = Action('CreateTrainingJob')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEndpointConfig = Action('DeleteEndpointConfig')
DeleteModel = Action('DeleteModel')
DeleteNotebookInstance = Action('DeleteNotebookInstance')
DeleteTags = Action('DeleteTags')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEndpointConfig = Action('DescribeEndpointConfig')
DescribeModel = Action('DescribeModel')
DescribeNotebookInstance = Action('DescribeNotebookInstance')
DescribeTrainingJob = Action('DescribeTrainingJob')
InvokeEndpoint = Action('InvokeEndpoint')
ListEndpointConfigs = Action('ListEndpointConfigs')
ListEndpoints = Action('ListEndpoints')
ListModels = Action('ListModels')
ListNotebookInstances = Action('ListNotebookInstances')
ListTags = Action('ListTags')
ListTrainingJobs = Action('ListTrainingJobs')
StartNotebookInstance = Action('StartNotebookInstance')
StopNotebookInstance = Action('StopNotebookInstance')
StopTrainingJob = Action('StopTrainingJob')
UpdateEndpoint = Action('UpdateEndpoint')
UpdateEndpointWeightsAndCapacities = \
    Action('UpdateEndpointWeightsAndCapacities')
UpdateNotebookInstance = Action('UpdateNotebookInstance')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Kinesis Analytics'
prefix = 'kinesisanalytics'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddApplicationInput = Action('AddApplicationInput')
AddApplicationOutput = Action('AddApplicationOutput')
AddApplicationReferenceDataSource = \
    Action('AddApplicationReferenceDataSource')
CreateApplication = Action('CreateApplication')
DeleteApplication = Action('DeleteApplication')
DeleteApplicationOutput = Action('DeleteApplicationOutput')
DeleteApplicationReferenceDataSource = \
    Action('DeleteApplicationReferenceDataSource')
DescribeApplication = Action('DescribeApplication')
DiscoverInputSchema = Action('DiscoverInputSchema')
GetApplicationState = Action('GetApplicationState')
ListApplications = Action('ListApplications')
StartApplication = Action('StartApplication')
StopApplication = Action('StopApplication')
UpdateApplication = Action('UpdateApplication')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CloudFormation'
prefix = 'cloudformation'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelUpdateStack = Action('CancelUpdateStack')
ContinueUpdateRollback = Action('ContinueUpdateRollback')
CreateChangeSet = Action('CreateChangeSet')
CreateStack = Action('CreateStack')
CreateUploadBucket = Action('CreateUploadBucket')
DeleteChangeSet = Action('DeleteChangeSet')
DeleteStack = Action('DeleteStack')
DescribeAccountLimits = Action('DescribeAccountLimits')
DescribeChangeSet = Action('DescribeChangeSet')
DescribeStackEvents = Action('DescribeStackEvents')
DescribeStackResource = Action('DescribeStackResource')
DescribeStackResources = Action('DescribeStackResources')
DescribeStacks = Action('DescribeStacks')
EstimateTemplateCost = Action('EstimateTemplateCost')
ExecuteChangeSet = Action('ExecuteChangeSet')
GetStackPolicy = Action('GetStackPolicy')
GetTemplate = Action('GetTemplate')
GetTemplateSummary = Action('GetTemplateSummary')
ListChangeSets = Action('ListChangeSets')
ListExports = Action('ListExports')
ListImports = Action('ListImports')
ListStackResources = Action('ListStackResources')
ListStacks = Action('ListStacks')
PreviewStackUpdate = Action('PreviewStackUpdate')
SetStackPolicy = Action('SetStackPolicy')
SignalResource = Action('SignalResource')
UpdateStack = Action('UpdateStack')
UpdateTerminationProtection = Action('UpdateTerminationProtection')
ValidateTemplate = Action('ValidateTemplate')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Chime'
prefix = 'chime'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptDelegate = Action('AcceptDelegate')
ActivateUsers = Action('ActivateUsers')
AddDomain = Action('AddDomain')
AddOrUpdateGroups = Action('AddOrUpdateGroups')
AuthorizeDirectory = Action('AuthorizeDirectory')
ConnectDirectory = Action('ConnectDirectory')
CreateAccount = Action('CreateAccount')
CreateCDRBucket = Action('CreateCDRBucket')
DeleteAccount = Action('DeleteAccount')
DeleteCDRBucket = Action('DeleteCDRBucket')
DeleteDelegate = Action('DeleteDelegate')
DeleteDomain = Action('DeleteDomain')
DeleteGroups = Action('DeleteGroups')
DisconnectDirectory = Action('DisconnectDirectory')
GetAccount = Action('GetAccount')
GetAccountResource = Action('GetAccountResource')
GetAccountSettings = Action('GetAccountSettings')
GetCDRBucket = Action('GetCDRBucket')
GetDomain = Action('GetDomain')
GetUser = Action('GetUser')
GetUserByEmail = Action('GetUserByEmail')
InviteDelegate = Action('InviteDelegate')
InviteUsers = Action('InviteUsers')
ListAccounts = Action('ListAccounts')
ListCDRBucket = Action('ListCDRBucket')
ListDelegates = Action('ListDelegates')
ListDirectories = Action('ListDirectories')
ListDomains = Action('ListDomains')
ListGroups = Action('ListGroups')
ListUsers = Action('ListUsers')
LogoutUser = Action('LogoutUser')
RenameAccount = Action('RenameAccount')
RenewDelegate = Action('RenewDelegate')
ResetAccountResource = Action('ResetAccountResource')
ResetPersonalPin = Action('ResetPersonalPin')
SubmitSupportRequest = Action('SubmitSupportRequest')
SuspendUsers = Action('SuspendUsers')
UnauthorizeDirectory = Action('UnauthorizeDirectory')
UpdateAccountResource = Action('UpdateAccountResource')
UpdateAccountSettings = Action('UpdateAccountSettings')
UpdateCDRBucket = Action('UpdateCDRBucket')
UpdateSupportedLicenses = Action('UpdateSupportedLicenses')
UpdateUserLicenses = Action('UpdateUserLicenses')
ValidateAccountResource = Action('ValidateAccountResource')
ValidateDelegate = Action('ValidateDelegate')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Service Catalog'
prefix = 'servicecatalog'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptPortfolioShare = Action('AcceptPortfolioShare')
AssociatePrincipalWithPortfolio = \
    Action('AssociatePrincipalWithPortfolio')
AssociateProductWithPortfolio = Action('AssociateProductWithPortfolio')
CreateConstraint = Action('CreateConstraint')
CreatePortfolio = Action('CreatePortfolio')
CreatePortfolioShare = Action('CreatePortfolioShare')
CreateProduct = Action('CreateProduct')
CreateProvisioningArtifact = Action('CreateProvisioningArtifact')
DeleteConstraint = Action('DeleteConstraint')
DeletePortfolio = Action('DeletePortfolio')
DeletePortfolioShare = Action('DeletePortfolioShare')
DeleteProduct = Action('DeleteProduct')
DeleteProvisioningArtifact = Action('DeleteProvisioningArtifact')
DescribeConstraint = Action('DescribeConstraint')
DescribePortfolio = Action('DescribePortfolio')
DescribeProduct = Action('DescribeProduct')
DescribeProductAsAdmin = Action('DescribeProductAsAdmin')
DescribeProductView = Action('DescribeProductView')
DescribeProvisioningArtifact = Action('DescribeProvisioningArtifact')
DescribeProvisioningParameters = Action('DescribeProvisioningParameters')
DescribeRecord = Action('DescribeRecord')
DisassociatePrincipalFromPortfolio = \
    Action('DisassociatePrincipalFromPortfolio')
DisassociateProductFromPortfolio = \
    Action('DisassociateProductFromPortfolio')
ListAcceptedPortfolioShares = Action('ListAcceptedPortfolioShares')
ListConstraintsForPortfolio = Action('ListConstraintsForPortfolio')
ListLaunchPaths = Action('ListLaunchPaths')
ListPortfolioAccess = Action('ListPortfolioAccess')
ListPortfolios = Action('ListPortfolios')
ListPortfoliosForProduct = Action('ListPortfoliosForProduct')
ListPrincipalsForPortfolio = Action('ListPrincipalsForPortfolio')
ListProvisioningArtifacts = Action('ListProvisioningArtifacts')
ListRecordHistory = Action('ListRecordHistory')
ProvisionProduct = Action('ProvisionProduct')
RejectPortfolioShare = Action('RejectPortfolioShare')
ScanProvisionedProducts = Action('ScanProvisionedProducts')
SearchProducts = Action('SearchProducts')
SearchProductsAsAdmin = Action('SearchProductsAsAdmin')
TerminateProvisionedProduct = Action('TerminateProvisionedProduct')
UpdateConstraint = Action('UpdateConstraint')
UpdatePortfolio = Action('UpdatePortfolio')
UpdateProduct = Action('UpdateProduct')
UpdateProvisionedProduct = Action('UpdateProvisionedProduct')
UpdateProvisioningArtifact = Action('UpdateProvisioningArtifact')



import unittest

from awacs.s3 import ARN


class TestARN(unittest.TestCase):
    def test_aws(self):
        arn = ARN("bucket/key", "us-east-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws:s3:::bucket/key")

    def test_cn(self):
        arn = ARN("bucket/key", "cn-north-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws-cn:s3:::bucket/key")

    def test_gov(self):
        arn = ARN("bucket/key", "us-gov-west-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws-us-gov:s3:::bucket/key")



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Pinpoint'
prefix = 'mobiletargeting'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCampaign = Action('CreateCampaign')
CreateImportJob = Action('CreateImportJob')
CreateSegment = Action('CreateSegment')
DeleteAdmChannel = Action('DeleteAdmChannel')
DeleteApnsChannel = Action('DeleteApnsChannel')
DeleteApnsSandboxChannel = Action('DeleteApnsSandboxChannel')
DeleteCampaign = Action('DeleteCampaign')
DeleteGcmChannel = Action('DeleteGcmChannel')
DeleteSegment = Action('DeleteSegment')
GetAdmChannel = Action('GetAdmChannel')
GetApnsChannel = Action('GetApnsChannel')
GetApnsSandboxChannel = Action('GetApnsSandboxChannel')
GetApplicationSettings = Action('GetApplicationSettings')
GetCampaign = Action('GetCampaign')
GetCampaignActivities = Action('GetCampaignActivities')
GetCampaignVersion = Action('GetCampaignVersion')
GetCampaignVersions = Action('GetCampaignVersions')
GetCampaigns = Action('GetCampaigns')
GetEndpoint = Action('GetEndpoint')
GetGcmChannel = Action('GetGcmChannel')
GetImportJob = Action('GetImportJob')
GetImportJobs = Action('GetImportJobs')
GetReports = Action('GetReports')
GetSegment = Action('GetSegment')
GetSegmentImportJobs = Action('GetSegmentImportJobs')
GetSegmentVersion = Action('GetSegmentVersion')
GetSegmentVersions = Action('GetSegmentVersions')
GetSegments = Action('GetSegments')
UpdateAdmChannel = Action('UpdateAdmChannel')
UpdateApnsChannel = Action('UpdateApnsChannel')
UpdateApnsSandboxChannel = Action('UpdateApnsSandboxChannel')
UpdateApplicationSettings = Action('UpdateApplicationSettings')
UpdateCampaign = Action('UpdateCampaign')
UpdateEndpoint = Action('UpdateEndpoint')
UpdateEndpointsBatch = Action('UpdateEndpointsBatch')
UpdateGcmChannel = Action('UpdateGcmChannel')
UpdateSegment = Action('UpdateSegment')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeBuild'
prefix = 'codebuild'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchDeleteBuilds = Action('BatchDeleteBuilds')
BatchGetBuilds = Action('BatchGetBuilds')
BatchGetProjects = Action('BatchGetProjects')
CreateProject = Action('CreateProject')
DeleteProject = Action('DeleteProject')
ListBuilds = Action('ListBuilds')
ListBuildsForProject = Action('ListBuildsForProject')
ListConnectedOAuthAccounts = Action('ListConnectedOAuthAccounts')
ListCuratedEnvironmentImages = Action('ListCuratedEnvironmentImages')
ListProjects = Action('ListProjects')
ListRepositories = Action('ListRepositories')
PersistOAuthToken = Action('PersistOAuthToken')
StartBuild = Action('StartBuild')
StopBuild = Action('StopBuild')
UpdateProject = Action('UpdateProject')



# Example taken from AWS docs:
# http://docs.aws.amazon.com/IAM/latest/UserGuide/
# ExampleIAMPolicies.html#iampolicy-example-s3homedir

from awacs.aws import Action, Allow, Condition
from awacs.aws import Policy, Statement
from awacs.aws import StringEquals, StringLike
import awacs.s3 as s3


pd = Policy(
    Statement=[
        Statement(
            Action=[s3.ListAllMyBuckets, s3.GetBucketLocation],
            Effect=Allow,
            Resource=[s3.ARN("*"), ],
        ),
        Statement(
            Action=[s3.ListBucket],
            Effect=Allow,
            Resource=[s3.ARN("myBucket")],
            Condition=Condition(
                StringEquals({
                    's3:prefix': ['', 'home/'],
                    's3:delimiter': ['/'],
                }),
            ),
        ),
        Statement(
            Action=[s3.ListBucket],
            Effect=Allow,
            Resource=[s3.ARN("myBucket")],
            Condition=Condition(
                StringLike("s3:prefix", ["home/${aws:username}/*"])
            ),
        ),
        Statement(
            Action=[Action("s3", "*")],
            Effect=Allow,
            Resource=[
                s3.ARN("myBucket/home/${aws:username}"),
                s3.ARN("myBucket/home/${aws:username}/*"),
            ],
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Config'
prefix = 'config'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DeleteConfigRule = Action('DeleteConfigRule')
DeleteConfigurationRecorder = Action('DeleteConfigurationRecorder')
DeleteDeliveryChannel = Action('DeleteDeliveryChannel')
DeleteEvaluationResults = Action('DeleteEvaluationResults')
DeliverConfigSnapshot = Action('DeliverConfigSnapshot')
DescribeComplianceByConfigRule = Action('DescribeComplianceByConfigRule')
DescribeComplianceByResource = Action('DescribeComplianceByResource')
DescribeConfigRuleEvaluationStatus = \
    Action('DescribeConfigRuleEvaluationStatus')
DescribeConfigRules = Action('DescribeConfigRules')
DescribeConfigurationRecorderStatus = \
    Action('DescribeConfigurationRecorderStatus')
DescribeConfigurationRecorders = Action('DescribeConfigurationRecorders')
DescribeDeliveryChannelStatus = Action('DescribeDeliveryChannelStatus')
DescribeDeliveryChannels = Action('DescribeDeliveryChannels')
GetComplianceDetailsByConfigRule = \
    Action('GetComplianceDetailsByConfigRule')
GetComplianceDetailsByResource = Action('GetComplianceDetailsByResource')
GetComplianceSummaryByConfigRule = \
    Action('GetComplianceSummaryByConfigRule')
GetComplianceSummaryByResourceType = \
    Action('GetComplianceSummaryByResourceType')
GetResourceConfigHistory = Action('GetResourceConfigHistory')
GetResources = Action('GetResources')
GetTagKeys = Action('GetTagKeys')
ListDiscoveredResources = Action('ListDiscoveredResources')
PutConfigRule = Action('PutConfigRule')
PutConfigurationRecorder = Action('PutConfigurationRecorder')
PutDeliveryChannel = Action('PutDeliveryChannel')
PutEvaluations = Action('PutEvaluations')
StartConfigRulesEvaluation = Action('StartConfigRulesEvaluation')
StartConfigurationRecorder = Action('StartConfigurationRecorder')
StopConfigurationRecorder = Action('StopConfigurationRecorder')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS OpsWorks Configuration Management'
prefix = 'opsworks-cm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateNode = Action('AssociateNode')
CreateBackup = Action('CreateBackup')
CreateServer = Action('CreateServer')
DeleteBackup = Action('DeleteBackup')
DeleteServer = Action('DeleteServer')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeBackups = Action('DescribeBackups')
DescribeEvents = Action('DescribeEvents')
DescribeNodeAssociationStatus = Action('DescribeNodeAssociationStatus')
DescribeServers = Action('DescribeServers')
DisassociateNode = Action('DisassociateNode')
RestoreServer = Action('RestoreServer')
StartMaintenance = Action('StartMaintenance')
UpdateServer = Action('UpdateServer')
UpdateServerEngineAttributes = Action('UpdateServerEngineAttributes')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudWatch'
prefix = 'cloudwatch'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DeleteAlarms = Action('DeleteAlarms')
DeleteDashboards = Action('DeleteDashboards')
DescribeAlarmHistory = Action('DescribeAlarmHistory')
DescribeAlarms = Action('DescribeAlarms')
DescribeAlarmsForMetric = Action('DescribeAlarmsForMetric')
DisableAlarmActions = Action('DisableAlarmActions')
EnableAlarmActions = Action('EnableAlarmActions')
GetDashboard = Action('GetDashboard')
GetMetricData = Action('GetMetricData')
GetMetricStatistics = Action('GetMetricStatistics')
ListDashboards = Action('ListDashboards')
ListMetrics = Action('ListMetrics')
PutDashboard = Action('PutDashboard')
PutMetricAlarm = Action('PutMetricAlarm')
PutMetricData = Action('PutMetricData')
SetAlarmState = Action('SetAlarmState')



# Example taken from AWS docs:
# http://docs.aws.amazon.com/AmazonECR/latest/userguide/ecr_managed_policies.html

from awacs.aws import Allow
from awacs.aws import Policy, Statement
import awacs.ecr as ecr


# AmazonEC2ContainerRegistryReadOnly
pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Action=[
                ecr.GetAuthorizationToken,
                ecr.BatchCheckLayerAvailability,
                ecr.GetDownloadUrlForLayer,
                ecr.GetRepositoryPolicy,
                ecr.DescribeRepositories,
                ecr.ListImages,
                ecr.BatchGetImage,
            ],
            Resource=['*']
        )
    ]
)


print(pd.to_json())



import warnings
# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SimpleDB'
prefix = 'sdb'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class SDB_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(SDB_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use sdb.ARN instead.",
                      FutureWarning)


BatchDeleteAttributes = Action('BatchDeleteAttributes')
BatchPutAttributes = Action('BatchPutAttributes')
CreateDomain = Action('CreateDomain')
DeleteAttributes = Action('DeleteAttributes')
DeleteDomain = Action('DeleteDomain')
DomainMetadata = Action('DomainMetadata')
GetAttributes = Action('GetAttributes')
ListDomains = Action('ListDomains')
PutAttributes = Action('PutAttributes')
Select = Action('Select')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Support'
prefix = 'support'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddAttachmentsToSet = Action('AddAttachmentsToSet')
AddCommunicationToCase = Action('AddCommunicationToCase')
CreateCase = Action('CreateCase')
DescribeAttachment = Action('DescribeAttachment')
DescribeCases = Action('DescribeCases')
DescribeCommunications = Action('DescribeCommunications')
DescribeServices = Action('DescribeServices')
DescribeSeverityLevels = Action('DescribeSeverityLevels')
DescribeTrustedAdvisorCheckRefreshStatuses = \
    Action('DescribeTrustedAdvisorCheckRefreshStatuses')
DescribeTrustedAdvisorCheckResult = \
    Action('DescribeTrustedAdvisorCheckResult')
DescribeTrustedAdvisorCheckSummaries = \
    Action('DescribeTrustedAdvisorCheckSummaries')
DescribeTrustedAdvisorChecks = Action('DescribeTrustedAdvisorChecks')
RefreshTrustedAdvisorCheck = Action('RefreshTrustedAdvisorCheck')
ResolveCase = Action('ResolveCase')



import warnings
# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SNS'
prefix = 'sns'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class SNS_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(SNS_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use sns.ARN instead.",
                      FutureWarning)


AddPermission = Action('AddPermission')
CheckIfPhoneNumberIsOptedOut = Action('CheckIfPhoneNumberIsOptedOut')
ConfirmSubscription = Action('ConfirmSubscription')
CreatePlatformApplication = Action('CreatePlatformApplication')
CreatePlatformEndpoint = Action('CreatePlatformEndpoint')
CreateTopic = Action('CreateTopic')
DeleteEndpoint = Action('DeleteEndpoint')
DeletePlatformApplication = Action('DeletePlatformApplication')
DeleteTopic = Action('DeleteTopic')
GetEndpointAttributes = Action('GetEndpointAttributes')
GetPlatformApplicationAttributes = \
    Action('GetPlatformApplicationAttributes')
GetSMSAttributes = Action('GetSMSAttributes')
GetSubscriptionAttributes = Action('GetSubscriptionAttributes')
GetTopicAttributes = Action('GetTopicAttributes')
ListEndpointsByPlatformApplication = \
    Action('ListEndpointsByPlatformApplication')
ListPhoneNumbersOptedOut = Action('ListPhoneNumbersOptedOut')
ListPlatformApplications = Action('ListPlatformApplications')
ListSubscriptions = Action('ListSubscriptions')
ListSubscriptionsByTopic = Action('ListSubscriptionsByTopic')
ListTopics = Action('ListTopics')
OptInPhoneNumber = Action('OptInPhoneNumber')
Publish = Action('Publish')
RemovePermission = Action('RemovePermission')
SetEndpointAttributes = Action('SetEndpointAttributes')
SetPlatformApplicationAttributes = \
    Action('SetPlatformApplicationAttributes')
SetSMSAttributes = Action('SetSMSAttributes')
SetSubscriptionAttributes = Action('SetSubscriptionAttributes')
SetTopicAttributes = Action('SetTopicAttributes')
Subscribe = Action('Subscribe')
Unsubscribe = Action('Unsubscribe')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaConvert'
prefix = 'mediaconvert'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelJob = Action('CancelJob')
CreateJob = Action('CreateJob')
CreateJobTemplate = Action('CreateJobTemplate')
CreatePreset = Action('CreatePreset')
CreateQueue = Action('CreateQueue')
DeleteJobTemplate = Action('DeleteJobTemplate')
DeletePreset = Action('DeletePreset')
DeleteQueue = Action('DeleteQueue')
DescribeEndpoint = Action('DescribeEndpoint')
GetJob = Action('GetJob')
GetJobTemplate = Action('GetJobTemplate')
GetPreset = Action('GetPreset')
GetQueue = Action('GetQueue')
ListJobTemplates = Action('ListJobTemplates')
ListJobs = Action('ListJobs')
ListPresets = Action('ListPresets')
ListQueues = Action('ListQueues')
UpdateJobTemplate = Action('UpdateJobTemplate')
UpdatePreset = Action('UpdatePreset')
UpdateQueue = Action('UpdateQueue')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon DynamoDB Accelerator (DAX)'
prefix = 'dax'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetItem = Action('BatchGetItem')
BatchWriteItem = Action('BatchWriteItem')
CreateCluster = Action('CreateCluster')
CreateParameterGroup = Action('CreateParameterGroup')
CreateSubnetGroup = Action('CreateSubnetGroup')
DecreaseReplicationFactor = Action('DecreaseReplicationFactor')
DefineAttributeList = Action('DefineAttributeList')
DefineAttributeListId = Action('DefineAttributeListId')
DefineKeySchema = Action('DefineKeySchema')
DeleteCluster = Action('DeleteCluster')
DeleteItem = Action('DeleteItem')
DeleteParameterGroup = Action('DeleteParameterGroup')
DeleteSubnetGroup = Action('DeleteSubnetGroup')
DescribeClusters = Action('DescribeClusters')
DescribeDefaultParameters = Action('DescribeDefaultParameters')
DescribeEvents = Action('DescribeEvents')
DescribeParameterGroups = Action('DescribeParameterGroups')
DescribeParameters = Action('DescribeParameters')
DescribeSubnetGroups = Action('DescribeSubnetGroups')
DescribeTable = Action('DescribeTable')
GetItem = Action('GetItem')
IncreaseReplicationFactor = Action('IncreaseReplicationFactor')
ListTables = Action('ListTables')
ListTags = Action('ListTags')
PutItem = Action('PutItem')
Query = Action('Query')
RebootNode = Action('RebootNode')
Scan = Action('Scan')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateCluster = Action('UpdateCluster')
UpdateItem = Action('UpdateItem')
UpdateParameterGroup = Action('UpdateParameterGroup')
UpdateSubnetGroup = Action('UpdateSubnetGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AWS Cloud Contact Center'
prefix = 'connect'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateInstance = Action('CreateInstance')
DescribeInstance = Action('DescribeInstance')
DestroyInstance = Action('DestroyInstance')
GetFederationToken = Action('GetFederationToken')
GetFederationTokens = Action('GetFederationTokens')
ListInstances = Action('ListInstances')
ModifyInstance = Action('ModifyInstance')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'QuickSight'
prefix = 'quicksight'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateAdmin = Action('CreateAdmin')
CreateGroup = Action('CreateGroup')
CreateGroupMembership = Action('CreateGroupMembership')
CreateReader = Action('CreateReader')
CreateUser = Action('CreateUser')
DeleteGroup = Action('DeleteGroup')
DeleteGroupMembership = Action('DeleteGroupMembership')
DeleteUser = Action('DeleteUser')
DescribeGroup = Action('DescribeGroup')
DescribeUser = Action('DescribeUser')
GetGroupMapping = Action('GetGroupMapping')
ListGroupMemberships = Action('ListGroupMemberships')
ListGroups = Action('ListGroups')
ListUserGroups = Action('ListUserGroups')
ListUsers = Action('ListUsers')
RegisterUser = Action('RegisterUser')
SearchDirectoryGroups = Action('SearchDirectoryGroups')
SetGroupMapping = Action('SetGroupMapping')
Subscribe = Action('Subscribe')
Unsubscribe = Action('Unsubscribe')
UpdateGroup = Action('UpdateGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Mobile Hub'
prefix = 'mobilehub'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateProject = Action('CreateProject')
CreateServiceRole = Action('CreateServiceRole')
DeleteProject = Action('DeleteProject')
DeployToStage = Action('DeployToStage')
DescribeBundle = Action('DescribeBundle')
ExportBundle = Action('ExportBundle')
ExportProject = Action('ExportProject')
GenerateProjectParameters = Action('GenerateProjectParameters')
GetProject = Action('GetProject')
GetProjectSnapshot = Action('GetProjectSnapshot')
ImportProject = Action('ImportProject')
ListAvailableConnectors = Action('ListAvailableConnectors')
ListAvailableFeatures = Action('ListAvailableFeatures')
ListAvailableRegions = Action('ListAvailableRegions')
ListBundles = Action('ListBundles')
ListProjects = Action('ListProjects')
SynchronizeProject = Action('SynchronizeProject')
UpdateProject = Action('UpdateProject')
ValidateProject = Action('ValidateProject')
VerifyServiceRole = Action('VerifyServiceRole')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeCommit'
prefix = 'codecommit'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetPullRequests = Action('BatchGetPullRequests')
BatchGetRepositories = Action('BatchGetRepositories')
CancelUploadArchive = Action('CancelUploadArchive')
CreateBranch = Action('CreateBranch')
CreatePullRequest = Action('CreatePullRequest')
CreateRepository = Action('CreateRepository')
DeleteBranch = Action('DeleteBranch')
DeleteCommentContent = Action('DeleteCommentContent')
DeleteRepository = Action('DeleteRepository')
DescribePullRequestEvents = Action('DescribePullRequestEvents')
GetBlob = Action('GetBlob')
GetBranch = Action('GetBranch')
GetComment = Action('GetComment')
GetCommentsForComparedCommit = Action('GetCommentsForComparedCommit')
GetCommentsForPullRequest = Action('GetCommentsForPullRequest')
GetCommit = Action('GetCommit')
GetCommitHistory = Action('GetCommitHistory')
GetCommitsFromMergeBase = Action('GetCommitsFromMergeBase')
GetDifferences = Action('GetDifferences')
GetMergeConflicts = Action('GetMergeConflicts')
GetObjectIdentifier = Action('GetObjectIdentifier')
GetPullRequest = Action('GetPullRequest')
GetReferences = Action('GetReferences')
GetRepository = Action('GetRepository')
GetRepositoryTriggers = Action('GetRepositoryTriggers')
GetTree = Action('GetTree')
GetUploadArchiveStatus = Action('GetUploadArchiveStatus')
GitPull = Action('GitPull')
GitPush = Action('GitPush')
ListBranches = Action('ListBranches')
ListPullRequests = Action('ListPullRequests')
ListRepositories = Action('ListRepositories')
MergePullRequestByFastForward = Action('MergePullRequestByFastForward')
PostCommentForComparedCommit = Action('PostCommentForComparedCommit')
PostCommentForPullRequest = Action('PostCommentForPullRequest')
PostCommentReply = Action('PostCommentReply')
PutFile = Action('PutFile')
PutRepositoryTriggers = Action('PutRepositoryTriggers')
TestRepositoryTriggers = Action('TestRepositoryTriggers')
UpdateComment = Action('UpdateComment')
UpdateDefaultBranch = Action('UpdateDefaultBranch')
UpdatePullRequestDescription = Action('UpdatePullRequestDescription')
UpdatePullRequestStatus = Action('UpdatePullRequestStatus')
UpdatePullRequestTitle = Action('UpdatePullRequestTitle')
UpdateRepositoryDescription = Action('UpdateRepositoryDescription')
UpdateRepositoryName = Action('UpdateRepositoryName')
UploadArchive = Action('UploadArchive')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Cognito Identity'
prefix = 'cognito-identity'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateIdentityPool = Action('CreateIdentityPool')
DeleteIdentities = Action('DeleteIdentities')
DeleteIdentityPool = Action('DeleteIdentityPool')
DescribeIdentity = Action('DescribeIdentity')
DescribeIdentityPool = Action('DescribeIdentityPool')
GetCredentialsForIdentity = Action('GetCredentialsForIdentity')
GetId = Action('GetId')
GetIdentityPoolRoles = Action('GetIdentityPoolRoles')
GetOpenIdToken = Action('GetOpenIdToken')
GetOpenIdTokenForDeveloperIdentity = \
    Action('GetOpenIdTokenForDeveloperIdentity')
ListIdentities = Action('ListIdentities')
ListIdentityPools = Action('ListIdentityPools')
LookupDeveloperIdentity = Action('LookupDeveloperIdentity')
MergeDeveloperIdentities = Action('MergeDeveloperIdentities')
SetIdentityPoolRoles = Action('SetIdentityPoolRoles')
UnlinkDeveloperIdentity = Action('UnlinkDeveloperIdentity')
UnlinkIdentity = Action('UnlinkIdentity')
UpdateIdentityPool = Action('UpdateIdentityPool')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkDocs'
prefix = 'workdocs'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AbortDocumentVersionUpload = Action('AbortDocumentVersionUpload')
ActivateUser = Action('ActivateUser')
AddResourcePermissions = Action('AddResourcePermissions')
AddUserToGroup = Action('AddUserToGroup')
CheckAlias = Action('CheckAlias')
CreateFolder = Action('CreateFolder')
CreateInstance = Action('CreateInstance')
CreateNotificationSubscription = Action('CreateNotificationSubscription')
CreateUser = Action('CreateUser')
DeactivateUser = Action('DeactivateUser')
DeleteDocument = Action('DeleteDocument')
DeleteFolder = Action('DeleteFolder')
DeleteFolderContents = Action('DeleteFolderContents')
DeleteInstance = Action('DeleteInstance')
DeleteNotificationSubscription = Action('DeleteNotificationSubscription')
DeleteUser = Action('DeleteUser')
DeregisterDirectory = Action('DeregisterDirectory')
DescribeAvailableDirectories = Action('DescribeAvailableDirectories')
DescribeDocumentVersions = Action('DescribeDocumentVersions')
DescribeFolderContents = Action('DescribeFolderContents')
DescribeInstances = Action('DescribeInstances')
DescribeNotificationSubscriptions = \
    Action('DescribeNotificationSubscriptions')
DescribeResourcePermissions = Action('DescribeResourcePermissions')
DescribeUsers = Action('DescribeUsers')
GetDocument = Action('GetDocument')
GetDocumentPath = Action('GetDocumentPath')
GetDocumentVersion = Action('GetDocumentVersion')
GetFolder = Action('GetFolder')
GetFolderPath = Action('GetFolderPath')
InitiateDocumentVersionUpload = Action('InitiateDocumentVersionUpload')
RegisterDirectory = Action('RegisterDirectory')
RemoveAllResourcePermissions = Action('RemoveAllResourcePermissions')
RemoveResourcePermission = Action('RemoveResourcePermission')
RemoveUserFromGroup = Action('RemoveUserFromGroup')
UpdateDocument = Action('UpdateDocument')
UpdateDocumentVersion = Action('UpdateDocumentVersion')
UpdateFolder = Action('UpdateFolder')
UpdateInstanceAlias = Action('UpdateInstanceAlias')
UpdateUser = Action('UpdateUser')



import warnings
# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon S3'
prefix = 's3'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        # account is empty for S3
        account = ''
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class S3_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(S3_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use s3.ARN instead.",
                      FutureWarning)


AbortMultipartUpload = Action('AbortMultipartUpload')
CreateBucket = Action('CreateBucket')
DeleteBucket = Action('DeleteBucket')
DeleteBucketPolicy = Action('DeleteBucketPolicy')
DeleteBucketWebsite = Action('DeleteBucketWebsite')
DeleteObject = Action('DeleteObject')
DeleteObjectTagging = Action('DeleteObjectTagging')
DeleteObjectVersion = Action('DeleteObjectVersion')
DeleteObjectVersionTagging = Action('DeleteObjectVersionTagging')
GetAccelerateConfiguration = Action('GetAccelerateConfiguration')
GetAnalyticsConfiguration = Action('GetAnalyticsConfiguration')
GetBucketAcl = Action('GetBucketAcl')
GetBucketCORS = Action('GetBucketCORS')
GetBucketLocation = Action('GetBucketLocation')
GetBucketLogging = Action('GetBucketLogging')
GetBucketNotification = Action('GetBucketNotification')
GetBucketPolicy = Action('GetBucketPolicy')
GetBucketRequestPayment = Action('GetBucketRequestPayment')
GetBucketTagging = Action('GetBucketTagging')
GetBucketVersioning = Action('GetBucketVersioning')
GetBucketWebsite = Action('GetBucketWebsite')
GetInventoryConfiguration = Action('GetInventoryConfiguration')
GetIpConfiguration = Action('GetIpConfiguration')
GetLifecycleConfiguration = Action('GetLifecycleConfiguration')
GetMetricsConfiguration = Action('GetMetricsConfiguration')
GetObject = Action('GetObject')
GetObjectAcl = Action('GetObjectAcl')
GetObjectTagging = Action('GetObjectTagging')
GetObjectTorrent = Action('GetObjectTorrent')
GetObjectVersion = Action('GetObjectVersion')
GetObjectVersionAcl = Action('GetObjectVersionAcl')
GetObjectVersionForReplication = Action('GetObjectVersionForReplication')
GetObjectVersionTagging = Action('GetObjectVersionTagging')
GetObjectVersionTorrent = Action('GetObjectVersionTorrent')
GetReplicationConfiguration = Action('GetReplicationConfiguration')
HeadBucket = Action('HeadBucket')
ListAllMyBuckets = Action('ListAllMyBuckets')
ListBucket = Action('ListBucket')
ListBucketByTags = Action('ListBucketByTags')
ListBucketMultipartUploads = Action('ListBucketMultipartUploads')
ListBucketVersions = Action('ListBucketVersions')
ListMultipartUploadParts = Action('ListMultipartUploadParts')
ListObjects = Action('ListObjects')
ObjectOwnerOverrideToBucketOwner = \
    Action('ObjectOwnerOverrideToBucketOwner')
PutAccelerateConfiguration = Action('PutAccelerateConfiguration')
PutAnalyticsConfiguration = Action('PutAnalyticsConfiguration')
PutBucketAcl = Action('PutBucketAcl')
PutBucketCORS = Action('PutBucketCORS')
PutBucketLogging = Action('PutBucketLogging')
PutBucketNotification = Action('PutBucketNotification')
PutBucketPolicy = Action('PutBucketPolicy')
PutBucketRequestPayment = Action('PutBucketRequestPayment')
PutBucketTagging = Action('PutBucketTagging')
PutBucketVersioning = Action('PutBucketVersioning')
PutBucketWebsite = Action('PutBucketWebsite')
PutInventoryConfiguration = Action('PutInventoryConfiguration')
PutIpConfiguration = Action('PutIpConfiguration')
PutLifecycleConfiguration = Action('PutLifecycleConfiguration')
PutMetricsConfiguration = Action('PutMetricsConfiguration')
PutObject = Action('PutObject')
PutObjectAcl = Action('PutObjectAcl')
PutObjectTagging = Action('PutObjectTagging')
PutObjectVersionAcl = Action('PutObjectVersionAcl')
PutObjectVersionTagging = Action('PutObjectVersionTagging')
PutReplicationConfiguration = Action('PutReplicationConfiguration')
ReplicateDelete = Action('ReplicateDelete')
ReplicateObject = Action('ReplicateObject')
ReplicateTags = Action('ReplicateTags')
RestoreObject = Action('RestoreObject')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lightsail'
prefix = 'lightsail'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AllocateStaticIp = Action('AllocateStaticIp')
AttachStaticIp = Action('AttachStaticIp')
CloseInstancePublicPorts = Action('CloseInstancePublicPorts')
CreateDomain = Action('CreateDomain')
CreateDomainEntry = Action('CreateDomainEntry')
CreateInstanceSnapshot = Action('CreateInstanceSnapshot')
CreateInstances = Action('CreateInstances')
CreateInstancesFromSnapshot = Action('CreateInstancesFromSnapshot')
CreateKeyPair = Action('CreateKeyPair')
DeleteDomain = Action('DeleteDomain')
DeleteDomainEntry = Action('DeleteDomainEntry')
DeleteInstance = Action('DeleteInstance')
DeleteInstanceSnapshot = Action('DeleteInstanceSnapshot')
DeleteKeyPair = Action('DeleteKeyPair')
DetachStaticIp = Action('DetachStaticIp')
DownloadDefaultKeyPair = Action('DownloadDefaultKeyPair')
GetActiveNames = Action('GetActiveNames')
GetBlueprints = Action('GetBlueprints')
GetBundles = Action('GetBundles')
GetDomain = Action('GetDomain')
GetDomains = Action('GetDomains')
GetInstance = Action('GetInstance')
GetInstanceAccessDetails = Action('GetInstanceAccessDetails')
GetInstanceMetricData = Action('GetInstanceMetricData')
GetInstancePortStates = Action('GetInstancePortStates')
GetInstanceSnapshot = Action('GetInstanceSnapshot')
GetInstanceSnapshots = Action('GetInstanceSnapshots')
GetInstanceState = Action('GetInstanceState')
GetInstances = Action('GetInstances')
GetKeyPair = Action('GetKeyPair')
GetKeyPairs = Action('GetKeyPairs')
GetOperation = Action('GetOperation')
GetOperations = Action('GetOperations')
GetOperationsForResource = Action('GetOperationsForResource')
GetRegions = Action('GetRegions')
GetStaticIp = Action('GetStaticIp')
GetStaticIps = Action('GetStaticIps')
ImportKeyPair = Action('ImportKeyPair')
IsVpcPeered = Action('IsVpcPeered')
OpenInstancePublicPorts = Action('OpenInstancePublicPorts')
PeerVpc = Action('PeerVpc')
RebootInstance = Action('RebootInstance')
ReleaseStaticIp = Action('ReleaseStaticIp')
StartInstance = Action('StartInstance')
StopInstance = Action('StopInstance')
UnpeerVpc = Action('UnpeerVpc')
UpdateDomainEntry = Action('UpdateDomainEntry')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

import warnings

from . import AWSHelperFn, AWSProperty

# Policy effect constants.
Allow = "Allow"
Deny = "Deny"

# Policy principal constants.
Everybody = "*"

# Policy condition key constants.
CurrentTime = "aws:CurrentTime"
EpochTime = "aws:EpochTime"
MultiFactorAuthAge = "aws:MultiFactorAuthAge"
MultiFactorAuthPresent = "aws:MultiFactorAuthPresent"
Referer = "aws:Referer"
SecureTransport = "aws:SecureTransport"
SourceAccount = "aws:SourceAccount"
SourceArn = "aws:SourceArn"
SourceIp = "aws:SourceIp"
UserAgent = "aws:UserAgent"


class Action(AWSHelperFn):
    def __init__(self, prefix, action=None):
        self.prefix = prefix
        if prefix == '*' and action:
            raise ValueError("Action not supported with wildcard prefix")
        else:
            self.action = action

    def JSONrepr(self):
        if self.prefix == '*' and not self.action:
            return self.prefix
        else:
            return ''.join([self.prefix, ":", self.action])


class BaseARN(AWSHelperFn):
    def __init__(self, service, resource, region='', account=''):
        region_string = region.lower()
        if region_string.startswith("cn-"):
            aws_partition = "aws-cn"
        elif region_string.startswith("us-gov"):
            aws_partition = "aws-us-gov"
        else:
            aws_partition = "aws"

        regionless = ['iam', 's3']
        if service in regionless:
            region = ""

        self.data = "arn:%s:%s:%s:%s:%s" % (
            aws_partition, service, region, account, resource)

    def JSONrepr(self):
        return self.data


class ARN(BaseARN):
    def __init__(self, service, resource, region='', account=''):
        super(ARN, self).__init__(service, resource, region, account)
        warnings.warn('This is going away. Either use a service specific '
                      'ARN class, or use the BaseARN class.', FutureWarning)


class ConditionElement(AWSHelperFn):
    def __init__(self, data, value=None):
        """Create a ConditionElement

        There are two supported ways to create a new ConditionElement.
        For a simple key/value pair use something of the form:
            StringEquals('s3:prefix': ['', 'home/']),
        If more than one condition is needed, pass a dict:
            StringEquals({
                's3:prefix': ['', 'home/'],
                's3:delimiter': ['/'],
            }),
        """
        self.cond_dict = None
        if value is not None:
            self.key = data
            self.value = value
        else:
            self.cond_dict = data

    def get_dict(self):
        if self.cond_dict:
            return self.cond_dict
        else:
            return {self.key: self.value}


class Condition(AWSHelperFn):
    def __init__(self, conditions):
        if isinstance(conditions, ConditionElement):
            self.conditions = [conditions]
        elif isinstance(conditions, list):
            for c in conditions:
                if not isinstance(c, ConditionElement):
                    raise ValueError(
                        "ConditionElement is type %s" % (type(c),))
            self.conditions = conditions
        else:
            raise TypeError

    def JSONrepr(self):
        d = {}
        for c in self.conditions:
            d[c.condition] = c.get_dict()
        return d


class Principal(AWSHelperFn):
    VALID_PRINCIPALS = ["AWS", "CanonicalUser", "Federated", "Service"]

    def __init__(self, principal, resources=None):
        if principal == "*":
            if resources:
                raise ValueError("Cannot provide resources if principal is "
                                 "'*'.")
            self.data = "*"
        else:
            if not resources:
                raise ValueError("Must provide resources with principal.")
            if principal not in self.VALID_PRINCIPALS:
                raise ValueError("Principal must be one of: %s" % (
                    ', '.join(self.VALID_PRINCIPALS))
                )
            self.data = {principal: resources}

    def JSONrepr(self):
        return self.data


class AWSPrincipal(Principal):
    def __init__(self, principals):
        sup = super(AWSPrincipal, self)
        sup.__init__('AWS', principals)


def effect(x):
    if x not in [Allow, Deny]:
        raise ValueError(x)
    return x


class Statement(AWSProperty):
    props = {
        'Action': ([Action], False),
        'Condition': (Condition, False),
        'Effect': (effect, True),
        'NotAction': (list, False),
        'NotPrincipal': (Principal, False),
        'Principal': (Principal, False),
        'Resource': (list, False),
        'NotResource': (list, False),
        'Sid': (basestring, False),
    }


class Policy(AWSProperty):
    props = {
        'Id': (basestring, False),
        'Statement': ([Statement], True),
        'Version': (basestring, False),
    }

    def JSONrepr(self):
        return self.properties


class PolicyDocument(Policy):
    pass


_condition_strings = [
    "ArnEquals",
    "ArnNotEquals",
    "ArnLike",
    "ArnNotLike",
    "Bool",
    "DateEquals",
    "DateNotEquals",
    "DateLessThan",
    "DateLessThanEquals",
    "DateGreaterThan",
    "DateGreaterThanEquals",
    "IpAddress",
    "NotIpAddress",
    "Null",
    "NumericEquals",
    "NumericNotEquals",
    "NumericLessThan",
    "NumericLessThanEquals",
    "NumericGreaterThan",
    "NumericGreaterThanEquals",
    "StringEquals",
    "StringNotEquals",
    "StringEqualsIgnoresCase",
    "StringLike",
    "StringNotLike",
]

_condition_qualifier_strings = [
    "ForAnyValue",
    "ForAllValues"
]


def make_condition(type_name, condition_name):
    globals()[type_name] = type(type_name, (ConditionElement,),
                                dict(condition=condition_name))
    globals()[type_name + "IfExists"] = type(type_name + "IfExists",
                                             (ConditionElement,),
                                             dict(
                                                  condition=condition_name +
                                                  "IfExists"))


# Create condition classes
for i in _condition_strings:
    make_condition(i, i)

    for qual in _condition_qualifier_strings:
        make_condition(qual+i, "%s:%s" % (qual, i))



import warnings
# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Identity And Access Management'
prefix = 'iam'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class IAM_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(IAM_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use iam.ARN instead.",
                      FutureWarning)


AddClientIDToOpenIDConnectProvider = \
    Action('AddClientIDToOpenIDConnectProvider')
AddRoleToInstanceProfile = Action('AddRoleToInstanceProfile')
AddUserToGroup = Action('AddUserToGroup')
AttachGroupPolicy = Action('AttachGroupPolicy')
AttachRolePolicy = Action('AttachRolePolicy')
AttachUserPolicy = Action('AttachUserPolicy')
ChangePassword = Action('ChangePassword')
CreateAccessKey = Action('CreateAccessKey')
CreateAccountAlias = Action('CreateAccountAlias')
CreateGroup = Action('CreateGroup')
CreateInstanceProfile = Action('CreateInstanceProfile')
CreateLoginProfile = Action('CreateLoginProfile')
CreateOpenIDConnectProvider = Action('CreateOpenIDConnectProvider')
CreatePolicy = Action('CreatePolicy')
CreatePolicyVersion = Action('CreatePolicyVersion')
CreateRole = Action('CreateRole')
CreateSAMLProvider = Action('CreateSAMLProvider')
CreateServiceLinkedRole = Action('CreateServiceLinkedRole')
CreateServiceSpecificCredential = \
    Action('CreateServiceSpecificCredential')
CreateUser = Action('CreateUser')
CreateVirtualMFADevice = Action('CreateVirtualMFADevice')
DeactivateMFADevice = Action('DeactivateMFADevice')
DeleteAccessKey = Action('DeleteAccessKey')
DeleteAccountAlias = Action('DeleteAccountAlias')
DeleteAccountPasswordPolicy = Action('DeleteAccountPasswordPolicy')
DeleteGroup = Action('DeleteGroup')
DeleteGroupPolicy = Action('DeleteGroupPolicy')
DeleteInstanceProfile = Action('DeleteInstanceProfile')
DeleteLoginProfile = Action('DeleteLoginProfile')
DeleteOpenIDConnectProvider = Action('DeleteOpenIDConnectProvider')
DeletePolicy = Action('DeletePolicy')
DeletePolicyVersion = Action('DeletePolicyVersion')
DeleteRole = Action('DeleteRole')
DeleteRolePolicy = Action('DeleteRolePolicy')
DeleteSAMLProvider = Action('DeleteSAMLProvider')
DeleteSSHPublicKey = Action('DeleteSSHPublicKey')
DeleteServerCertificate = Action('DeleteServerCertificate')
DeleteServiceLinkedRole = Action('DeleteServiceLinkedRole')
DeleteServiceSpecificCredential = \
    Action('DeleteServiceSpecificCredential')
DeleteSigningCertificate = Action('DeleteSigningCertificate')
DeleteUser = Action('DeleteUser')
DeleteUserPolicy = Action('DeleteUserPolicy')
DeleteVirtualMFADevice = Action('DeleteVirtualMFADevice')
DetachGroupPolicy = Action('DetachGroupPolicy')
DetachRolePolicy = Action('DetachRolePolicy')
DetachUserPolicy = Action('DetachUserPolicy')
EnableMFADevice = Action('EnableMFADevice')
FinalizeSmsMfaRegistration = Action('FinalizeSmsMfaRegistration')
GenerateCredentialReport = Action('GenerateCredentialReport')
GenerateServiceLastAccessedDetails = \
    Action('GenerateServiceLastAccessedDetails')
GetAccessKeyLastUsed = Action('GetAccessKeyLastUsed')
GetAccountAuthorizationDetails = Action('GetAccountAuthorizationDetails')
GetAccountPasswordPolicy = Action('GetAccountPasswordPolicy')
GetAccountSummary = Action('GetAccountSummary')
GetContextKeysForCustomPolicy = Action('GetContextKeysForCustomPolicy')
GetContextKeysForPrincipalPolicy = \
    Action('GetContextKeysForPrincipalPolicy')
GetCredentialReport = Action('GetCredentialReport')
GetGroup = Action('GetGroup')
GetGroupPolicy = Action('GetGroupPolicy')
GetInstanceProfile = Action('GetInstanceProfile')
GetLoginProfile = Action('GetLoginProfile')
GetOpenIDConnectProvider = Action('GetOpenIDConnectProvider')
GetPolicy = Action('GetPolicy')
GetPolicyVersion = Action('GetPolicyVersion')
GetRole = Action('GetRole')
GetRolePolicy = Action('GetRolePolicy')
GetSAMLProvider = Action('GetSAMLProvider')
GetSSHPublicKey = Action('GetSSHPublicKey')
GetServerCertificate = Action('GetServerCertificate')
GetServiceLastAccessedDetails = Action('GetServiceLastAccessedDetails')
GetServiceLastAccessedDetailsWithEntities = \
    Action('GetServiceLastAccessedDetailsWithEntities')
GetServiceLinkedRoleDeletionStatus = \
    Action('GetServiceLinkedRoleDeletionStatus')
GetUser = Action('GetUser')
GetUserPolicy = Action('GetUserPolicy')
ListAccessKeys = Action('ListAccessKeys')
ListAccountAliases = Action('ListAccountAliases')
ListAttachedGroupPolicies = Action('ListAttachedGroupPolicies')
ListAttachedRolePolicies = Action('ListAttachedRolePolicies')
ListAttachedUserPolicies = Action('ListAttachedUserPolicies')
ListEntitiesForPolicy = Action('ListEntitiesForPolicy')
ListGroupPolicies = Action('ListGroupPolicies')
ListGroups = Action('ListGroups')
ListGroupsForUser = Action('ListGroupsForUser')
ListInstanceProfiles = Action('ListInstanceProfiles')
ListInstanceProfilesForRole = Action('ListInstanceProfilesForRole')
ListMFADevices = Action('ListMFADevices')
ListOpenIDConnectProviders = Action('ListOpenIDConnectProviders')
ListPolicies = Action('ListPolicies')
ListPoliciesGrantingServiceAccess = \
    Action('ListPoliciesGrantingServiceAccess')
ListPolicyVersions = Action('ListPolicyVersions')
ListRolePolicies = Action('ListRolePolicies')
ListRoles = Action('ListRoles')
ListSAMLProviders = Action('ListSAMLProviders')
ListSSHPublicKeys = Action('ListSSHPublicKeys')
ListServerCertificates = Action('ListServerCertificates')
ListServiceSpecificCredentials = Action('ListServiceSpecificCredentials')
ListSigningCertificates = Action('ListSigningCertificates')
ListUserPolicies = Action('ListUserPolicies')
ListUsers = Action('ListUsers')
ListVirtualMFADevices = Action('ListVirtualMFADevices')
PassRole = Action('PassRole')
PutGroupPolicy = Action('PutGroupPolicy')
PutRolePolicy = Action('PutRolePolicy')
PutUserPolicy = Action('PutUserPolicy')
RemoveClientIDFromOpenIDConnectProvider = \
    Action('RemoveClientIDFromOpenIDConnectProvider')
RemoveRoleFromInstanceProfile = Action('RemoveRoleFromInstanceProfile')
RemoveUserFromGroup = Action('RemoveUserFromGroup')
RequestSmsMfaRegistration = Action('RequestSmsMfaRegistration')
ResetServiceSpecificCredential = Action('ResetServiceSpecificCredential')
ResyncMFADevice = Action('ResyncMFADevice')
SetDefaultPolicyVersion = Action('SetDefaultPolicyVersion')
SimulateCustomPolicy = Action('SimulateCustomPolicy')
SimulatePrincipalPolicy = Action('SimulatePrincipalPolicy')
UpdateAccessKey = Action('UpdateAccessKey')
UpdateAccountPasswordPolicy = Action('UpdateAccountPasswordPolicy')
UpdateAssumeRolePolicy = Action('UpdateAssumeRolePolicy')
UpdateGroup = Action('UpdateGroup')
UpdateLoginProfile = Action('UpdateLoginProfile')
UpdateOpenIDConnectProviderThumbprint = \
    Action('UpdateOpenIDConnectProviderThumbprint')
UpdateRoleDescription = Action('UpdateRoleDescription')
UpdateSAMLProvider = Action('UpdateSAMLProvider')
UpdateSSHPublicKey = Action('UpdateSSHPublicKey')
UpdateServerCertificate = Action('UpdateServerCertificate')
UpdateServiceSpecificCredential = \
    Action('UpdateServiceSpecificCredential')
UpdateSigningCertificate = Action('UpdateSigningCertificate')
UpdateUser = Action('UpdateUser')
UploadSSHPublicKey = Action('UploadSSHPublicKey')
UploadServerCertificate = Action('UploadServerCertificate')
UploadSigningCertificate = Action('UploadSigningCertificate')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Elastic Load Balancing'
prefix = 'elasticloadbalancing'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTags = Action('AddTags')
ApplySecurityGroupsToLoadBalancer = \
    Action('ApplySecurityGroupsToLoadBalancer')
AttachLoadBalancerToSubnets = Action('AttachLoadBalancerToSubnets')
ConfigureHealthCheck = Action('ConfigureHealthCheck')
CreateAppCookieStickinessPolicy = \
    Action('CreateAppCookieStickinessPolicy')
CreateLBCookieStickinessPolicy = Action('CreateLBCookieStickinessPolicy')
CreateLoadBalancer = Action('CreateLoadBalancer')
CreateLoadBalancerListeners = Action('CreateLoadBalancerListeners')
CreateLoadBalancerPolicy = Action('CreateLoadBalancerPolicy')
DeleteLoadBalancer = Action('DeleteLoadBalancer')
DeleteLoadBalancerListeners = Action('DeleteLoadBalancerListeners')
DeleteLoadBalancerPolicy = Action('DeleteLoadBalancerPolicy')
DeregisterInstancesFromLoadBalancer = \
    Action('DeregisterInstancesFromLoadBalancer')
DescribeInstanceHealth = Action('DescribeInstanceHealth')
DescribeLoadBalancerAttributes = Action('DescribeLoadBalancerAttributes')
DescribeLoadBalancerPolicies = Action('DescribeLoadBalancerPolicies')
DescribeLoadBalancerPolicyTypes = \
    Action('DescribeLoadBalancerPolicyTypes')
DescribeLoadBalancers = Action('DescribeLoadBalancers')
DescribeTags = Action('DescribeTags')
DetachLoadBalancerFromSubnets = Action('DetachLoadBalancerFromSubnets')
DisableAvailabilityZonesForLoadBalancer = \
    Action('DisableAvailabilityZonesForLoadBalancer')
EnableAvailabilityZonesForLoadBalancer = \
    Action('EnableAvailabilityZonesForLoadBalancer')
ModifyLoadBalancerAttributes = Action('ModifyLoadBalancerAttributes')
RegisterInstancesWithLoadBalancer = \
    Action('RegisterInstancesWithLoadBalancer')
RemoveTags = Action('RemoveTags')
SetLoadBalancerListenerSSLCertificate = \
    Action('SetLoadBalancerListenerSSLCertificate')
SetLoadBalancerPoliciesForBackendServer = \
    Action('SetLoadBalancerPoliciesForBackendServer')
SetLoadBalancerPoliciesOfListener = \
    Action('SetLoadBalancerPoliciesOfListener')
AddTags = Action('AddTags')
CreateListener = Action('CreateListener')
CreateLoadBalancer = Action('CreateLoadBalancer')
CreateRule = Action('CreateRule')
CreateTargetGroup = Action('CreateTargetGroup')
DeleteListener = Action('DeleteListener')
DeleteLoadBalancer = Action('DeleteLoadBalancer')
DeleteRule = Action('DeleteRule')
DeleteTargetGroup = Action('DeleteTargetGroup')
DeregisterTargets = Action('DeregisterTargets')
DescribeListeners = Action('DescribeListeners')
DescribeLoadBalancerAttributes = Action('DescribeLoadBalancerAttributes')
DescribeLoadBalancers = Action('DescribeLoadBalancers')
DescribeRules = Action('DescribeRules')
DescribeSSLPolicies = Action('DescribeSSLPolicies')
DescribeTags = Action('DescribeTags')
DescribeTargetGroupAttributes = Action('DescribeTargetGroupAttributes')
DescribeTargetGroups = Action('DescribeTargetGroups')
DescribeTargetHealth = Action('DescribeTargetHealth')
ModifyListener = Action('ModifyListener')
ModifyLoadBalancerAttributes = Action('ModifyLoadBalancerAttributes')
ModifyRule = Action('ModifyRule')
ModifyTargetGroup = Action('ModifyTargetGroup')
ModifyTargetGroupAttributes = Action('ModifyTargetGroupAttributes')
RegisterTargets = Action('RegisterTargets')
RemoveTags = Action('RemoveTags')
SetIpAddressType = Action('SetIpAddressType')
SetRulePriorities = Action('SetRulePriorities')
SetSecurityGroups = Action('SetSecurityGroups')
SetSubnets = Action('SetSubnets')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT Analytics'
prefix = 'iotanalytics'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateChannel = Action('CreateChannel')
CreateDataset = Action('CreateDataset')
CreateDatasetContent = Action('CreateDatasetContent')
CreateDatastore = Action('CreateDatastore')
CreatePipeline = Action('CreatePipeline')
DeleteChannel = Action('DeleteChannel')
DeleteDataset = Action('DeleteDataset')
DeleteDatasetContent = Action('DeleteDatasetContent')
DeleteDatastore = Action('DeleteDatastore')
DeletePipeline = Action('DeletePipeline')
DescribeChannel = Action('DescribeChannel')
DescribeDataset = Action('DescribeDataset')
DescribeDatastore = Action('DescribeDatastore')
DescribePipeline = Action('DescribePipeline')
GetDatasetContent = Action('GetDatasetContent')
ListChannels = Action('ListChannels')
ListDatasets = Action('ListDatasets')
ListDatastores = Action('ListDatastores')
ListPipelines = Action('ListPipelines')
UpdateDataset = Action('UpdateDataset')
UpdatePipeline = Action('UpdatePipeline')



# Example taken from AWS docs:
# http://docs.aws.amazon.com/AmazonECS/latest/developerguide/instance_IAM_role.html

from awacs.aws import Allow
from awacs.aws import Policy, Statement
import awacs.ecs as aecs
import awacs.ecr as aecr
import awacs.logs as alogs


pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Action=[aecs.CreateCluster,
                    aecs.DeregisterContainerInstance,
                    aecs.DiscoverPollEndpoint,
                    aecs.Poll,
                    aecs.RegisterContainerInstance,
                    aecs.StartTelemetrySession,
                    aecr.GetAuthorizationToken,
                    aecr.BatchCheckLayerAvailability,
                    aecr.GetDownloadUrlForLayer,
                    aecr.BatchGetImage,
                    alogs.CreateLogStream,
                    alogs.PutLogEvents,
                    aecs.Action("Submit*")],
            Resource=["*"]
        )
    ]
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Alexa for Business'
prefix = 'a4b'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateDeviceWithRoom = Action('AssociateDeviceWithRoom')
AssociateSkillGroupWithRoom = Action('AssociateSkillGroupWithRoom')
CreateProfile = Action('CreateProfile')
CreateRoom = Action('CreateRoom')
CreateSkillGroup = Action('CreateSkillGroup')
CreateUser = Action('CreateUser')
DeleteProfile = Action('DeleteProfile')
DeleteRoom = Action('DeleteRoom')
DeleteRoomSkillParameter = Action('DeleteRoomSkillParameter')
DeleteSkillGroup = Action('DeleteSkillGroup')
DeleteUser = Action('DeleteUser')
DisassociateDeviceFromRoom = Action('DisassociateDeviceFromRoom')
DisassociateSkillGroupFromRoom = Action('DisassociateSkillGroupFromRoom')
GetDevice = Action('GetDevice')
GetProfile = Action('GetProfile')
GetRoom = Action('GetRoom')
GetRoomSkillParameter = Action('GetRoomSkillParameter')
GetSkillGroup = Action('GetSkillGroup')
ListSkills = Action('ListSkills')
ListTags = Action('ListTags')
PutRoomSkillParameter = Action('PutRoomSkillParameter')
ResolveRoom = Action('ResolveRoom')
RevokeInvitation = Action('RevokeInvitation')
SearchDevices = Action('SearchDevices')
SearchProfiles = Action('SearchProfiles')
SearchRooms = Action('SearchRooms')
SearchSkillGroups = Action('SearchSkillGroups')
SearchUsers = Action('SearchUsers')
SendInvitation = Action('SendInvitation')
StartDeviceSync = Action('StartDeviceSync')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDevice = Action('UpdateDevice')
UpdateProfile = Action('UpdateProfile')
UpdateRoom = Action('UpdateRoom')
UpdateSkillGroup = Action('UpdateSkillGroup')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Directory Service'
prefix = 'ds'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddIpRoutes = Action('AddIpRoutes')
AddTagsToResource = Action('AddTagsToResource')
AuthorizeApplication = Action('AuthorizeApplication')
CancelSchemaExtension = Action('CancelSchemaExtension')
ConnectDirectory = Action('ConnectDirectory')
CreateAlias = Action('CreateAlias')
CreateComputer = Action('CreateComputer')
CreateConditionalForwarder = Action('CreateConditionalForwarder')
CreateDirectory = Action('CreateDirectory')
CreateMicrosoftAD = Action('CreateMicrosoftAD')
CreateSnapshot = Action('CreateSnapshot')
CreateTrust = Action('CreateTrust')
DeleteConditionalForwarder = Action('DeleteConditionalForwarder')
DeleteDirectory = Action('DeleteDirectory')
DeleteSnapshot = Action('DeleteSnapshot')
DeleteTrust = Action('DeleteTrust')
DeregisterEventTopic = Action('DeregisterEventTopic')
DescribeConditionalForwarders = Action('DescribeConditionalForwarders')
DescribeDirectories = Action('DescribeDirectories')
DescribeEventTopics = Action('DescribeEventTopics')
DescribeSnapshots = Action('DescribeSnapshots')
DescribeTrusts = Action('DescribeTrusts')
DisableRadius = Action('DisableRadius')
DisableSso = Action('DisableSso')
EnableRadius = Action('EnableRadius')
EnableSso = Action('EnableSso')
GetDirectoryLimits = Action('GetDirectoryLimits')
GetSnapshotLimits = Action('GetSnapshotLimits')
ListAuthorizedApplications = Action('ListAuthorizedApplications')
ListIpRoutes = Action('ListIpRoutes')
ListSchemaExtensions = Action('ListSchemaExtensions')
ListTagsForResource = Action('ListTagsForResource')
RegisterEventTopic = Action('RegisterEventTopic')
RemoveIpRoutes = Action('RemoveIpRoutes')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
RestoreFromSnapshot = Action('RestoreFromSnapshot')
StartSchemaExtension = Action('StartSchemaExtension')
UnauthorizeApplication = Action('UnauthorizeApplication')
UpdateConditionalForwarder = Action('UpdateConditionalForwarder')
UpdateRadius = Action('UpdateRadius')
VerifyTrust = Action('VerifyTrust')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Direct Connect'
prefix = 'directconnect'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AllocateConnectionOnInterconnect = \
    Action('AllocateConnectionOnInterconnect')
AllocatePrivateVirtualInterface = \
    Action('AllocatePrivateVirtualInterface')
AllocatePublicVirtualInterface = Action('AllocatePublicVirtualInterface')
ConfirmConnection = Action('ConfirmConnection')
ConfirmPrivateVirtualInterface = Action('ConfirmPrivateVirtualInterface')
ConfirmPublicVirtualInterface = Action('ConfirmPublicVirtualInterface')
CreateConnection = Action('CreateConnection')
CreateInterconnect = Action('CreateInterconnect')
CreatePrivateVirtualInterface = Action('CreatePrivateVirtualInterface')
CreatePublicVirtualInterface = Action('CreatePublicVirtualInterface')
DeleteConnection = Action('DeleteConnection')
DeleteInterconnect = Action('DeleteInterconnect')
DeleteVirtualInterface = Action('DeleteVirtualInterface')
DescribeConnectionLoa = Action('DescribeConnectionLoa')
DescribeConnections = Action('DescribeConnections')
DescribeConnectionsOnInterconnect = \
    Action('DescribeConnectionsOnInterconnect')
DescribeInterconnectLoa = Action('DescribeInterconnectLoa')
DescribeInterconnects = Action('DescribeInterconnects')
DescribeLocations = Action('DescribeLocations')
DescribeVirtualGateways = Action('DescribeVirtualGateways')
DescribeVirtualInterfaces = Action('DescribeVirtualInterfaces')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkMail'
prefix = 'workmail'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddMembersToGroup = Action('AddMembersToGroup')
CreateGroup = Action('CreateGroup')
CreateMailDomain = Action('CreateMailDomain')
CreateMailUser = Action('CreateMailUser')
CreateOrganization = Action('CreateOrganization')
CreateResource = Action('CreateResource')
DeleteMailDomain = Action('DeleteMailDomain')
DeleteMobileDevice = Action('DeleteMobileDevice')
DeleteOrganization = Action('DeleteOrganization')
DescribeDirectories = Action('DescribeDirectories')
DescribeKmsKeys = Action('DescribeKmsKeys')
DescribeMailDomains = Action('DescribeMailDomains')
DescribeMailGroups = Action('DescribeMailGroups')
DescribeMailUsers = Action('DescribeMailUsers')
DescribeOrganizations = Action('DescribeOrganizations')
DisableMailGroups = Action('DisableMailGroups')
DisableMailUsers = Action('DisableMailUsers')
EnableMailDomain = Action('EnableMailDomain')
EnableMailGroups = Action('EnableMailGroups')
EnableMailUsers = Action('EnableMailUsers')
GetMailDomainDetails = Action('GetMailDomainDetails')
GetMailGroupDetails = Action('GetMailGroupDetails')
GetMailUserDetails = Action('GetMailUserDetails')
GetMobileDeviceDetails = Action('GetMobileDeviceDetails')
GetMobileDevicesForUser = Action('GetMobileDevicesForUser')
GetMobilePolicyDetails = Action('GetMobilePolicyDetails')
ListMembersInMailGroup = Action('ListMembersInMailGroup')
RemoveMembersFromGroup = Action('RemoveMembersFromGroup')
ResetUserPassword = Action('ResetUserPassword')
SearchMembers = Action('SearchMembers')
SetAdmin = Action('SetAdmin')
SetDefaultMailDomain = Action('SetDefaultMailDomain')
SetMailGroupDetails = Action('SetMailGroupDetails')
SetMailUserDetails = Action('SetMailUserDetails')
SetMobilePolicyDetails = Action('SetMobilePolicyDetails')
WipeMobileDevice = Action('WipeMobileDevice')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudFront'
prefix = 'cloudfront'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCloudFrontOriginAccessIdentity = \
    Action('CreateCloudFrontOriginAccessIdentity')
CreateDistribution = Action('CreateDistribution')
CreateDistributionWithTags = Action('CreateDistributionWithTags')
CreateInvalidation = Action('CreateInvalidation')
CreateStreamingDistribution = Action('CreateStreamingDistribution')
CreateStreamingDistributionWithTags = \
    Action('CreateStreamingDistributionWithTags')
DeleteCloudFrontOriginAccessIdentity = \
    Action('DeleteCloudFrontOriginAccessIdentity')
DeleteDistribution = Action('DeleteDistribution')
DeleteStreamingDistribution = Action('DeleteStreamingDistribution')
GetCloudFrontOriginAccessIdentity = \
    Action('GetCloudFrontOriginAccessIdentity')
GetCloudFrontOriginAccessIdentityConfig = \
    Action('GetCloudFrontOriginAccessIdentityConfig')
GetDistribution = Action('GetDistribution')
GetDistributionConfig = Action('GetDistributionConfig')
GetInvalidation = Action('GetInvalidation')
GetStreamingDistribution = Action('GetStreamingDistribution')
GetStreamingDistributionConfig = Action('GetStreamingDistributionConfig')
ListCloudFrontOriginAccessIdentities = \
    Action('ListCloudFrontOriginAccessIdentities')
ListDistributions = Action('ListDistributions')
ListDistributionsByWebACLId = Action('ListDistributionsByWebACLId')
ListInvalidations = Action('ListInvalidations')
ListStreamingDistributions = Action('ListStreamingDistributions')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateCloudFrontOriginAccessIdentity = \
    Action('UpdateCloudFrontOriginAccessIdentity')
UpdateDistribution = Action('UpdateDistribution')
UpdateStreamingDistribution = Action('UpdateStreamingDistribution')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon WorkSpaces'
prefix = 'workspaces'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateTags = Action('CreateTags')
CreateWorkspaces = Action('CreateWorkspaces')
DeleteTags = Action('DeleteTags')
DescribeTags = Action('DescribeTags')
DescribeWorkspaceBundles = Action('DescribeWorkspaceBundles')
DescribeWorkspaceDirectories = Action('DescribeWorkspaceDirectories')
DescribeWorkspaces = Action('DescribeWorkspaces')
DescribeWorkspacesConnectionStatus = \
    Action('DescribeWorkspacesConnectionStatus')
ModifyWorkspaceProperties = Action('ModifyWorkspaceProperties')
RebootWorkspaces = Action('RebootWorkspaces')
RebuildWorkspaces = Action('RebuildWorkspaces')
StartWorkspaces = Action('StartWorkspaces')
StopWorkspaces = Action('StopWorkspaces')
TerminateWorkspaces = Action('TerminateWorkspaces')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CloudWatch Events'
prefix = 'events'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


DeleteRule = Action('DeleteRule')
DescribeRule = Action('DescribeRule')
DisableRule = Action('DisableRule')
EnableRule = Action('EnableRule')
ListRuleNamesByTarget = Action('ListRuleNamesByTarget')
ListRules = Action('ListRules')
ListTargetsByRule = Action('ListTargetsByRule')
PutEvents = Action('PutEvents')
PutRule = Action('PutRule')
PutTargets = Action('PutTargets')
RemoveTargets = Action('RemoveTargets')
TestEventPattern = Action('TestEventPattern')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Database Migration Service'
prefix = 'dms'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddTagsToResource = Action('AddTagsToResource')
CreateEndpoint = Action('CreateEndpoint')
CreateReplicationInstance = Action('CreateReplicationInstance')
CreateReplicationSubnetGroup = Action('CreateReplicationSubnetGroup')
CreateReplicationTask = Action('CreateReplicationTask')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEventSubscription = Action('DeleteEventSubscription')
DeleteReplicationInstance = Action('DeleteReplicationInstance')
DeleteReplicationSubnetGroup = Action('DeleteReplicationSubnetGroup')
DeleteReplicationTask = Action('DeleteReplicationTask')
DescribeAccountAttributes = Action('DescribeAccountAttributes')
DescribeCertificates = Action('DescribeCertificates')
DescribeConnections = Action('DescribeConnections')
DescribeEndpointTypes = Action('DescribeEndpointTypes')
DescribeEndpoints = Action('DescribeEndpoints')
DescribeEventCategories = Action('DescribeEventCategories')
DescribeEventSubscriptions = Action('DescribeEventSubscriptions')
DescribeEvents = Action('DescribeEvents')
DescribeOrderableReplicationInstances = \
    Action('DescribeOrderableReplicationInstances')
DescribeRefreshSchemasStatus = Action('DescribeRefreshSchemasStatus')
DescribeReplicationInstances = Action('DescribeReplicationInstances')
DescribeReplicationSubnetGroups = \
    Action('DescribeReplicationSubnetGroups')
DescribeReplicationTasks = Action('DescribeReplicationTasks')
DescribeSchemas = Action('DescribeSchemas')
DescribeTableStatistics = Action('DescribeTableStatistics')
ListTagsForResource = Action('ListTagsForResource')
ModifyEndpoint = Action('ModifyEndpoint')
ModifyEventSubscription = Action('ModifyEventSubscription')
ModifyReplicationInstance = Action('ModifyReplicationInstance')
ModifyReplicationSubnetGroup = Action('ModifyReplicationSubnetGroup')
ModifyReplicationTask = Action('ModifyReplicationTask')
RefreshSchemas = Action('RefreshSchemas')
RemoveTagsFromResource = Action('RemoveTagsFromResource')
StartReplicationTask = Action('StartReplicationTask')
StopReplicationTask = Action('StopReplicationTask')
TestConnection = Action('TestConnection')



from setuptools import setup, find_packages

setup(
    name='awacs',
    version='0.8.2',
    description="AWS Access Policy Language creation library",
    author="Mark Peek",
    author_email="mark@peek.org",
    url="https://github.com/cloudtools/awacs",
    license="New BSD license",
    packages=find_packages(),
    test_suite="tests",
    use_2to3=True,
    requires=['slimit'],
)



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon GameLift'
prefix = 'gamelift'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateAlias = Action('CreateAlias')
CreateBuild = Action('CreateBuild')
CreateFleet = Action('CreateFleet')
CreateGameSession = Action('CreateGameSession')
CreatePlayerSession = Action('CreatePlayerSession')
CreatePlayerSessions = Action('CreatePlayerSessions')
DeleteAlias = Action('DeleteAlias')
DeleteBuild = Action('DeleteBuild')
DeleteFleet = Action('DeleteFleet')
DeleteScalingPolicy = Action('DeleteScalingPolicy')
DescribeAlias = Action('DescribeAlias')
DescribeBuild = Action('DescribeBuild')
DescribeEC2InstanceLimits = Action('DescribeEC2InstanceLimits')
DescribeFleetAttributes = Action('DescribeFleetAttributes')
DescribeFleetCapacity = Action('DescribeFleetCapacity')
DescribeFleetEvents = Action('DescribeFleetEvents')
DescribeFleetPortSettings = Action('DescribeFleetPortSettings')
DescribeFleetUtilization = Action('DescribeFleetUtilization')
DescribeGameSessionDetails = Action('DescribeGameSessionDetails')
DescribeGameSessions = Action('DescribeGameSessions')
DescribeInstances = Action('DescribeInstances')
DescribePlayerSessions = Action('DescribePlayerSessions')
DescribeRuntimeConfiguration = Action('DescribeRuntimeConfiguration')
DescribeScalingPolicies = Action('DescribeScalingPolicies')
GetGameSessionLogUrl = Action('GetGameSessionLogUrl')
GetInstanceAccess = Action('GetInstanceAccess')
ListAliases = Action('ListAliases')
ListBuilds = Action('ListBuilds')
ListFleets = Action('ListFleets')
PutScalingPolicy = Action('PutScalingPolicy')
RequestUploadCredentials = Action('RequestUploadCredentials')
ResolveAlias = Action('ResolveAlias')
SearchGameSessions = Action('SearchGameSessions')
UpdateAlias = Action('UpdateAlias')
UpdateBuild = Action('UpdateBuild')
UpdateFleetAttributes = Action('UpdateFleetAttributes')
UpdateFleetCapacity = Action('UpdateFleetCapacity')
UpdateFleetPortSettings = Action('UpdateFleetPortSettings')
UpdateGameSession = Action('UpdateGameSession')
UpdateRuntimeConfiguration = Action('UpdateRuntimeConfiguration')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Step Functions'
prefix = 'states'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateActivity = Action('CreateActivity')
CreateStateMachine = Action('CreateStateMachine')
DeleteActivity = Action('DeleteActivity')
DeleteStateMachine = Action('DeleteStateMachine')
DescribeActivity = Action('DescribeActivity')
DescribeExecution = Action('DescribeExecution')
DescribeStateMachine = Action('DescribeStateMachine')
DescribeStateMachineForExecution = \
    Action('DescribeStateMachineForExecution')
GetActivityTask = Action('GetActivityTask')
GetExecutionHistory = Action('GetExecutionHistory')
ListActivities = Action('ListActivities')
ListExecutions = Action('ListExecutions')
ListStateMachines = Action('ListStateMachines')
SendTaskFailure = Action('SendTaskFailure')
SendTaskHeartbeat = Action('SendTaskHeartbeat')
SendTaskSuccess = Action('SendTaskSuccess')
StartExecution = Action('StartExecution')
StopExecution = Action('StopExecution')
UpdateStateMachine = Action('UpdateStateMachine')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Route53 Domains'
prefix = 'route53domains'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CheckDomainAvailability = Action('CheckDomainAvailability')
DeleteTagsForDomain = Action('DeleteTagsForDomain')
DisableDomainAutoRenew = Action('DisableDomainAutoRenew')
DisableDomainTransferLock = Action('DisableDomainTransferLock')
EnableDomainAutoRenew = Action('EnableDomainAutoRenew')
EnableDomainTransferLock = Action('EnableDomainTransferLock')
GetContactReachabilityStatus = Action('GetContactReachabilityStatus')
GetDomainDetail = Action('GetDomainDetail')
GetDomainSuggestions = Action('GetDomainSuggestions')
GetOperationDetail = Action('GetOperationDetail')
ListDomains = Action('ListDomains')
ListOperations = Action('ListOperations')
ListTagsForDomain = Action('ListTagsForDomain')
RegisterDomain = Action('RegisterDomain')
RenewDomain = Action('RenewDomain')
ResendContactReachabilityEmail = Action('ResendContactReachabilityEmail')
RetrieveDomainAuthCode = Action('RetrieveDomainAuthCode')
TransferDomain = Action('TransferDomain')
UpdateDomainContact = Action('UpdateDomainContact')
UpdateDomainContactPrivacy = Action('UpdateDomainContactPrivacy')
UpdateDomainNameservers = Action('UpdateDomainNameservers')
UpdateTagsForDomain = Action('UpdateTagsForDomain')
ViewBilling = Action('ViewBilling')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT'
prefix = 'iot'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptCertificateTransfer = Action('AcceptCertificateTransfer')
AssociateTargetsWithJob = Action('AssociateTargetsWithJob')
AttachPolicy = Action('AttachPolicy')
AttachPrincipalPolicy = Action('AttachPrincipalPolicy')
AttachThingPrincipal = Action('AttachThingPrincipal')
CancelCertificateTransfer = Action('CancelCertificateTransfer')
CancelJob = Action('CancelJob')
ClearDefaultAuthorizer = Action('ClearDefaultAuthorizer')
Connect = Action('Connect')
CreateAuthorizer = Action('CreateAuthorizer')
CreateCertificateFromCsr = Action('CreateCertificateFromCsr')
CreateJob = Action('CreateJob')
CreateKeysAndCertificate = Action('CreateKeysAndCertificate')
CreateOTAUpdateJob = Action('CreateOTAUpdateJob')
CreatePolicy = Action('CreatePolicy')
CreatePolicyVersion = Action('CreatePolicyVersion')
CreateRoleAlias = Action('CreateRoleAlias')
CreateStream = Action('CreateStream')
CreateThing = Action('CreateThing')
CreateThingType = Action('CreateThingType')
CreateTopicRule = Action('CreateTopicRule')
DeleteAuthorizer = Action('DeleteAuthorizer')
DeleteCACertificate = Action('DeleteCACertificate')
DeleteCertificate = Action('DeleteCertificate')
DeleteOTAUpdateJob = Action('DeleteOTAUpdateJob')
DeletePolicy = Action('DeletePolicy')
DeletePolicyVersion = Action('DeletePolicyVersion')
DeleteRegistrationCode = Action('DeleteRegistrationCode')
DeleteRoleAlias = Action('DeleteRoleAlias')
DeleteStream = Action('DeleteStream')
DeleteThing = Action('DeleteThing')
DeleteThingShadow = Action('DeleteThingShadow')
DeleteThingType = Action('DeleteThingType')
DeleteTopicRule = Action('DeleteTopicRule')
DeprecateThingType = Action('DeprecateThingType')
DescribeAuthorizer = Action('DescribeAuthorizer')
DescribeCACertificate = Action('DescribeCACertificate')
DescribeCertificate = Action('DescribeCertificate')
DescribeDefaultAuthorizer = Action('DescribeDefaultAuthorizer')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeIndex = Action('DescribeIndex')
DescribeJob = Action('DescribeJob')
DescribeJobExecution = Action('DescribeJobExecution')
DescribeRoleAlias = Action('DescribeRoleAlias')
DescribeStream = Action('DescribeStream')
DescribeThing = Action('DescribeThing')
DescribeThingType = Action('DescribeThingType')
DetachPolicy = Action('DetachPolicy')
DetachPrincipalPolicy = Action('DetachPrincipalPolicy')
DetachThingPrincipal = Action('DetachThingPrincipal')
DisableTopicRule = Action('DisableTopicRule')
EnableTopicRule = Action('EnableTopicRule')
GetEffectivePolicies = Action('GetEffectivePolicies')
GetIndexingConfiguration = Action('GetIndexingConfiguration')
GetJobDocument = Action('GetJobDocument')
GetLoggingOptions = Action('GetLoggingOptions')
GetOTAUpdateJob = Action('GetOTAUpdateJob')
GetPolicy = Action('GetPolicy')
GetPolicyVersion = Action('GetPolicyVersion')
GetRegistrationCode = Action('GetRegistrationCode')
GetThingShadow = Action('GetThingShadow')
GetTopicRule = Action('GetTopicRule')
ListAttachedPolicies = Action('ListAttachedPolicies')
ListAuthorizers = Action('ListAuthorizers')
ListCACertificates = Action('ListCACertificates')
ListCertificates = Action('ListCertificates')
ListCertificatesByCA = Action('ListCertificatesByCA')
ListIndices = Action('ListIndices')
ListJobExecutionsForJob = Action('ListJobExecutionsForJob')
ListJobExecutionsForThing = Action('ListJobExecutionsForThing')
ListJobs = Action('ListJobs')
ListOTAUpdateJobs = Action('ListOTAUpdateJobs')
ListOutgoingCertificates = Action('ListOutgoingCertificates')
ListPolicies = Action('ListPolicies')
ListPolicyPrincipals = Action('ListPolicyPrincipals')
ListPolicyVersions = Action('ListPolicyVersions')
ListPrincipalPolicies = Action('ListPrincipalPolicies')
ListPrincipalThings = Action('ListPrincipalThings')
ListRoleAliases = Action('ListRoleAliases')
ListStreams = Action('ListStreams')
ListTargetsForPolicy = Action('ListTargetsForPolicy')
ListThingPrincipals = Action('ListThingPrincipals')
ListThingTypes = Action('ListThingTypes')
ListThings = Action('ListThings')
ListTopicRules = Action('ListTopicRules')
Publish = Action('Publish')
Receive = Action('Receive')
RegisterCACertificate = Action('RegisterCACertificate')
RegisterCertificate = Action('RegisterCertificate')
RejectCertificateTransfer = Action('RejectCertificateTransfer')
ReplaceTopicRule = Action('ReplaceTopicRule')
SearchIndex = Action('SearchIndex')
SetDefaultAuthorizer = Action('SetDefaultAuthorizer')
SetDefaultPolicyVersion = Action('SetDefaultPolicyVersion')
SetLoggingOptions = Action('SetLoggingOptions')
Subscribe = Action('Subscribe')
TestAuthorization = Action('TestAuthorization')
TestInvokeAuthorizer = Action('TestInvokeAuthorizer')
TransferCertificate = Action('TransferCertificate')
UpdateAuthorizer = Action('UpdateAuthorizer')
UpdateCACertificate = Action('UpdateCACertificate')
UpdateCertificate = Action('UpdateCertificate')
UpdateIndexingConfiguration = Action('UpdateIndexingConfiguration')
UpdateRoleAlias = Action('UpdateRoleAlias')
UpdateStream = Action('UpdateStream')
UpdateThing = Action('UpdateThing')
UpdateThingShadow = Action('UpdateThingShadow')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Application Discovery'
prefix = 'discovery'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateConfigurationItemsToApplication = \
    Action('AssociateConfigurationItemsToApplication')
CreateApplication = Action('CreateApplication')
CreateTags = Action('CreateTags')
DeleteApplications = Action('DeleteApplications')
DeleteTags = Action('DeleteTags')
DescribeAgents = Action('DescribeAgents')
DescribeConfigurations = Action('DescribeConfigurations')
DescribeExportConfigurations = Action('DescribeExportConfigurations')
DescribeTags = Action('DescribeTags')
DisassociateConfigurationItemsFromApplication = \
    Action('DisassociateConfigurationItemsFromApplication')
ExportConfigurations = Action('ExportConfigurations')
GetDiscoverySummary = Action('GetDiscoverySummary')
ListConfigurations = Action('ListConfigurations')
ListServerNeighbors = Action('ListServerNeighbors')
StartDataCollectionByAgentIds = Action('StartDataCollectionByAgentIds')
StartExportTask = Action('StartExportTask')
StopDataCollectionByAgentIds = Action('StopDataCollectionByAgentIds')
UpdateApplication = Action('UpdateApplication')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Simple Workflow Service'
prefix = 'swf'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelTimer = Action('CancelTimer')
CancelWorkflowExecution = Action('CancelWorkflowExecution')
CompleteWorkflowExecution = Action('CompleteWorkflowExecution')
ContinueAsNewWorkflowExecution = Action('ContinueAsNewWorkflowExecution')
CountClosedWorkflowExecutions = Action('CountClosedWorkflowExecutions')
CountOpenWorkflowExecutions = Action('CountOpenWorkflowExecutions')
CountPendingActivityTasks = Action('CountPendingActivityTasks')
CountPendingDecisionTasks = Action('CountPendingDecisionTasks')
DeprecateActivityType = Action('DeprecateActivityType')
DeprecateDomain = Action('DeprecateDomain')
DeprecateWorkflowType = Action('DeprecateWorkflowType')
DescribeActivityType = Action('DescribeActivityType')
DescribeDomain = Action('DescribeDomain')
DescribeWorkflowExecution = Action('DescribeWorkflowExecution')
DescribeWorkflowType = Action('DescribeWorkflowType')
FailWorkflowExecution = Action('FailWorkflowExecution')
GetWorkflowExecutionHistory = Action('GetWorkflowExecutionHistory')
ListActivityTypes = Action('ListActivityTypes')
ListClosedWorkflowExecutions = Action('ListClosedWorkflowExecutions')
ListDomains = Action('ListDomains')
ListOpenWorkflowExecutions = Action('ListOpenWorkflowExecutions')
ListWorkflowTypes = Action('ListWorkflowTypes')
PollForActivityTask = Action('PollForActivityTask')
PollForDecisionTask = Action('PollForDecisionTask')
RecordActivityTaskHeartbeat = Action('RecordActivityTaskHeartbeat')
RecordMarker = Action('RecordMarker')
RegisterActivityType = Action('RegisterActivityType')
RegisterDomain = Action('RegisterDomain')
RegisterWorkflowType = Action('RegisterWorkflowType')
RequestCancelActivityTask = Action('RequestCancelActivityTask')
RequestCancelExternalWorkflowExecution = \
    Action('RequestCancelExternalWorkflowExecution')
RequestCancelWorkflowExecution = Action('RequestCancelWorkflowExecution')
RespondActivityTaskCanceled = Action('RespondActivityTaskCanceled')
RespondActivityTaskCompleted = Action('RespondActivityTaskCompleted')
RespondActivityTaskFailed = Action('RespondActivityTaskFailed')
RespondDecisionTaskCompleted = Action('RespondDecisionTaskCompleted')
ScheduleActivityTask = Action('ScheduleActivityTask')
SignalExternalWorkflowExecution = \
    Action('SignalExternalWorkflowExecution')
SignalWorkflowExecution = Action('SignalWorkflowExecution')
StartChildWorkflowExecution = Action('StartChildWorkflowExecution')
StartTimer = Action('StartTimer')
StartWorkflowExecution = Action('StartWorkflowExecution')
TerminateWorkflowExecution = Action('TerminateWorkflowExecution')
